@@ -1,6 +1,8 @@
 pub mod season;
+pub mod moving_median;
 
 pub use season::Season;
+pub use moving_median::MovingMedian;
 use crate::plotable::Plotable;
 
 use std::fmt;
@@ -8,6 +10,7 @@ use std::fmt;
 use plotlib::view::{View, CategoricalView, ContinuousView};
 use plotlib::repr::{Plot, CategoricalRepresentation};
 use plotlib::style::{PointStyle, LineStyle, PointMarker};
+
 /// Holds the data of the series
 /// its implied that every unit of data represents a unit of time
 #[derive(Clone)]
@@ -26,8 +29,9 @@ impl TimeSeries {
             dom_ran: None,
             style: Default::default()
         }
-    }
+    }    
 
+    /// Returns all (x,y) values
     fn get_data(&self) ->Vec<(f64, f64)> {
         let mut vec = Vec::new();
         for i in 0..self.data.len() {
@@ -38,9 +42,18 @@ impl TimeSeries {
         vec
     }
 
+    /// Returns all y values
+    pub fn get_range(&self) -> Vec<f64> {
+        self.data.clone()
+    }
+
     pub fn style(&self) -> Style {
         self.style.clone()
     }
+
+    pub fn len(&self) -> usize {
+        self.data.len()
+    }
 }
 
 #[derive(Clone)]
